summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorschmidt <douglascraigschmidt@users.noreply.github.com>1998-03-22 00:54:48 +0000
committerschmidt <douglascraigschmidt@users.noreply.github.com>1998-03-22 00:54:48 +0000
commit067b05bbb1427cc16a993bcf1f919713e02712b3 (patch)
tree06a6d81c5289064a0a88354fa5bf87badf251588
parentcde12565d74d8980568965745ca2d0692802b55c (diff)
downloadATCD-067b05bbb1427cc16a993bcf1f919713e02712b3.tar.gz
*** empty log message ***
-rw-r--r--TAO/TAO_IDL/be/be_attribute.cpp12
-rw-r--r--TAO/TAO_IDL/be/be_operation.cpp8
-rw-r--r--TAO/TAO_IDL/be/be_visitor_args.cpp8
-rw-r--r--TAO/TAO_IDL/be/be_visitor_operation.cpp34
-rw-r--r--TAO/TAO_IDL/be_include/be_codegen.h16
-rw-r--r--TAO/TAO_IDL/be_include/be_visitor_args.h6
-rw-r--r--TAO/TAO_IDL/be_include/be_visitor_operation.h10
-rw-r--r--TAO/tao/interp.cpp3
8 files changed, 49 insertions, 48 deletions
diff --git a/TAO/TAO_IDL/be/be_attribute.cpp b/TAO/TAO_IDL/be/be_attribute.cpp
index eb0a0325216..5f5e6977a1d 100644
--- a/TAO/TAO_IDL/be/be_attribute.cpp
+++ b/TAO/TAO_IDL/be/be_attribute.cpp
@@ -273,8 +273,8 @@ be_attribute::gen_client_stubs (void)
*cs << "}" << nl;
*cs << "this->Release (); // QueryInterface has bumped up our refcount" << nl;
- // call do_call with appropriate number of arguments
- *cs << "istub->do_call (env, &_get_" << this->flatname () <<
+ // call do_static_call with appropriate number of arguments
+ *cs << "istub->do_static_call (env, &_get_" << this->flatname () <<
"_calldata";
if (bt->node_type () == AST_Decl::NT_typedef)
@@ -392,7 +392,7 @@ be_attribute::gen_client_stubs (void)
*cs << "}" << nl;
*cs << "this->Release (); // QueryInterface has bumped up our refcount" << nl;
- // do any pre do_call stuff with the lone IN parameter
+ // do any pre do_static_call stuff with the lone IN parameter
cg->push (TAO_CodeGen::TAO_ATTRIBUTE_PRE_DOCALL_CS);
if (!s || (s->gen_code (bt, this) == -1))
{
@@ -403,8 +403,8 @@ be_attribute::gen_client_stubs (void)
}
cg->pop ();
- // call do_call with appropriate number of arguments
- *cs << "istub->do_call (env, &_set_" << this->flatname () <<
+ // call do_static_call with appropriate number of arguments
+ *cs << "istub->do_static_call (env, &_set_" << this->flatname () <<
"_calldata, 0"; // no return value
cg->push (TAO_CodeGen::TAO_ATTRIBUTE_DOCALL_CS);
@@ -420,7 +420,7 @@ be_attribute::gen_client_stubs (void)
cg->pop ();
*cs << ");" << nl;
- // do any post do_call processing
+ // do any post do_static_call processing
cg->push (TAO_CodeGen::TAO_ATTRIBUTE_POST_DOCALL_CS);
s = cg->make_state ();
if (!s || !bt || (s->gen_code (bt, this) == -1))
diff --git a/TAO/TAO_IDL/be/be_operation.cpp b/TAO/TAO_IDL/be/be_operation.cpp
index 88dfcdfd5ea..602ab706e1d 100644
--- a/TAO/TAO_IDL/be/be_operation.cpp
+++ b/TAO/TAO_IDL/be/be_operation.cpp
@@ -467,7 +467,7 @@ be_operation::gen_client_stubs (void)
*cs << "this->Release (); "
<< "// QueryInterface has bumped up our refcount" << nl;
- // do any pre do_call stuff with arguments
+ // do any pre do_static_call stuff with arguments
cg->push (TAO_CodeGen::TAO_ARGUMENT_PRE_DOCALL_CS);
if (be_scope::gen_client_stubs () == -1)
{
@@ -478,8 +478,8 @@ be_operation::gen_client_stubs (void)
}
cg->pop ();
- // call do_call with appropriate number of arguments
- *cs << "istub->do_call (env, &" << this->flatname ()
+ // call do_static_call with appropriate number of arguments
+ *cs << "istub->do_static_call (env, &" << this->flatname ()
<< "_calldata";
// if our return type is not void, then pass the address of retval
@@ -531,7 +531,7 @@ be_operation::gen_client_stubs (void)
cg->pop ();
*cs << ");" << nl;
- // do any post do_call stuff with arguments
+ // do any post do_static_call stuff with arguments
cg->push (TAO_CodeGen::TAO_ARGUMENT_POST_DOCALL_CS);
if (be_scope::gen_client_stubs () == -1)
{
diff --git a/TAO/TAO_IDL/be/be_visitor_args.cpp b/TAO/TAO_IDL/be/be_visitor_args.cpp
index ec01a51770c..da3bcf765db 100644
--- a/TAO/TAO_IDL/be/be_visitor_args.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_args.cpp
@@ -526,7 +526,7 @@ be_visitor_args_pre_docall_cs::visit_predefined_type (be_predefined_type *node)
else
bt = node;
- // pre do_call processing is valid only for pseudo objects and for Any
+ // pre do_static_call processing is valid only for pseudo objects and for Any
switch (node->pt ())
{
case AST_PredefinedType::PT_pseudo:
@@ -718,13 +718,13 @@ be_visitor_args_pre_docall_cs::visit_typedef (be_typedef *node)
}
// ****************************************************************************
-// visitor for argument passing to do_call. The do_call method takes a variable
+// visitor for argument passing to do_static_call. The do_static_call method takes a variable
// number of parameters. The total number of parameters is determined by the
// "calldata" parameter that must be passed before the variable list
-// starts. Each argument to the do_call is considered to be of type "void *".
+// starts. Each argument to the do_static_call is considered to be of type "void *".
// Hence we pass the address of each argument. The case for _out is a bit
// tricky where we must first retrieve the pointer, allocate memory and pass it
-// to do_call. This is done in the "pre_do_call" processing.
+// to do_static_call. This is done in the "pre_do_static_call" processing.
// ****************************************************************************
be_visitor_args_docall_cs::be_visitor_args_docall_cs (be_visitor_context *ctx)
diff --git a/TAO/TAO_IDL/be_include/be_codegen.h b/TAO/TAO_IDL/be_include/be_codegen.h
index 8f7d1d7d675..98be252ffe2 100644
--- a/TAO/TAO_IDL/be_include/be_codegen.h
+++ b/TAO/TAO_IDL/be_include/be_codegen.h
@@ -61,10 +61,10 @@ public:
TAO_ARGUMENT_ARGLIST_OTHERS, // ... in other cases
TAO_ARGUMENT_PRE_DOCALL_CS, // preprocessing of argument
// variable before passing to
- // do_call (in stub)
- TAO_ARGUMENT_DOCALL_CS, // passing argument variable to do_call
+ // do_static_call (in stub)
+ TAO_ARGUMENT_DOCALL_CS, // passing argument variable to do_static_call
TAO_ARGUMENT_POST_DOCALL_CS, // postprocessing of argument
- // variable after do_call
+ // variable after do_static_call
TAO_ARGUMENT_VARDECL_SS, // declaration of argument
// variable in skeleton (server)
TAO_ARGUMENT_MARSHAL_SS, // passing argument node to the
@@ -200,13 +200,13 @@ public:
TAO_OPERATION_RETVAL_PRE_DOCALL_CS, // preprocessing for return value
// before sending over the wire
TAO_OPERATION_ARG_PRE_DOCALL_CS, // preprocessing of arguments
- // before do_call
+ // before do_static_call
TAO_OPERATION_RETVAL_DOCALL_CS, // passing the return type
- // variable to do_call
- TAO_OPERATION_ARG_DOCALL_CS, // passing argument variable to do_call
+ // variable to do_static_call
+ TAO_OPERATION_ARG_DOCALL_CS, // passing argument variable to do_static_call
TAO_OPERATION_RETVAL_POST_DOCALL_CS, // processing of return type
- // after do_call
- TAO_OPERATION_ARG_POST_DOCALL_CS, // processing of arg after do_call
+ // after do_static_call
+ TAO_OPERATION_ARG_POST_DOCALL_CS, // processing of arg after do_static_call
TAO_OPERATION_RETVAL_RETURN_CS, // returning the return type variable
TAO_OPERATION_RETVAL_DECL_SS, // return type decl in skeleton
TAO_OPERATION_ARG_DECL_SS, // argument decl in skeleton
diff --git a/TAO/TAO_IDL/be_include/be_visitor_args.h b/TAO/TAO_IDL/be_include/be_visitor_args.h
index 12d4ef95307..78ceb5b70b2 100644
--- a/TAO/TAO_IDL/be_include/be_visitor_args.h
+++ b/TAO/TAO_IDL/be_include/be_visitor_args.h
@@ -131,7 +131,7 @@ class be_visitor_args_pre_docall_cs : public be_visitor_args
// be_visitor_args_docall_cs
//
// = DESCRIPTION
- // Code to be generated when making the do_call
+ // Code to be generated when making the do_static_call
//
public:
be_visitor_args_pre_docall_cs (be_visitor_context *ctx);
@@ -187,7 +187,7 @@ class be_visitor_args_docall_cs : public be_visitor_args
// be_visitor_args_docall_cs
//
// = DESCRIPTION
- // Code to be generated when making the do_call
+ // Code to be generated when making the do_static_call
//
public:
be_visitor_args_docall_cs (be_visitor_context *ctx);
@@ -243,7 +243,7 @@ class be_visitor_args_post_docall_cs : public be_visitor_args
// be_visitor_args_post_docall_cs
//
// = DESCRIPTION
- // Code to be generated after the do_call is done
+ // Code to be generated after the do_static_call is done
//
public:
be_visitor_args_post_docall_cs (be_visitor_context *ctx);
diff --git a/TAO/TAO_IDL/be_include/be_visitor_operation.h b/TAO/TAO_IDL/be_include/be_visitor_operation.h
index 33dec049cff..a45d70d4b48 100644
--- a/TAO/TAO_IDL/be_include/be_visitor_operation.h
+++ b/TAO/TAO_IDL/be_include/be_visitor_operation.h
@@ -332,7 +332,7 @@ public:
};
// ************************************************************
-// Operation visitor for preprocessing before do_call is invoked
+// Operation visitor for preprocessing before do_static_call is invoked
// ************************************************************
class be_visitor_operation_rettype_pre_docall_cs :public be_visitor_decl
@@ -342,7 +342,7 @@ class be_visitor_operation_rettype_pre_docall_cs :public be_visitor_decl
// be_visitor_operation_rettype_pre_docall_cs
//
// = DESCRIPTION
- // This is a visitor to generate any pre processing before the do_call is
+ // This is a visitor to generate any pre processing before the do_static_call is
// made
//
public:
@@ -379,7 +379,7 @@ public:
};
// ************************************************************
-// Operation visitor for passing return variable to do_call
+// Operation visitor for passing return variable to do_static_call
// ************************************************************
class be_visitor_operation_rettype_docall_cs :public be_visitor_decl
@@ -432,7 +432,7 @@ public:
};
// ************************************************************
-// Operation visitor for postprocessing after do_call is invoked
+// Operation visitor for postprocessing after do_static_call is invoked
// ************************************************************
class be_visitor_operation_rettype_post_docall_cs :public be_visitor_decl
@@ -442,7 +442,7 @@ class be_visitor_operation_rettype_post_docall_cs :public be_visitor_decl
// be_visitor_operation_rettype_psot_docall_cs
//
// = DESCRIPTION
- // This is a visitor to generate any post processing after the do_call is
+ // This is a visitor to generate any post processing after the do_static_call is
// made
//
public:
diff --git a/TAO/tao/interp.cpp b/TAO/tao/interp.cpp
index d9f125e1b13..6baf82873c6 100644
--- a/TAO/tao/interp.cpp
+++ b/TAO/tao/interp.cpp
@@ -6,7 +6,8 @@
#include "tao/corba.h"
-TAO_Table_Element TAO_IIOP_Interpreter::table_[CORBA::TC_KIND_COUNT] =
+TAO_IIOP_Interpreter::Table_Element
+TAO_IIOP_Interpreter::table_[CORBA::TC_KIND_COUNT] =
{
{ 0, 1, 0 }, // CORBA::tk_null
{ 0, 1, 0 }, // CORBA::tk_void
diff --git a/TAO/TAO_IDL/be/be_visitor_operation.cpp b/TAO/TAO_IDL/be/be_visitor_operation.cpp
index c988a6cccf0..2a1ccbf3444 100644
--- a/TAO/TAO_IDL/be/be_visitor_operation.cpp
+++ b/TAO/TAO_IDL/be/be_visitor_operation.cpp
@@ -347,14 +347,14 @@ be_visitor_operation_cs::visit_operation (be_operation *node)
{
// STEP 5B:
// generate code that retrieves the underlying stub object and then
// invokes do_call on it.
*os << "STUB_Object *istub = this->stubobj (_tao_environment);" << be_nl
<< "if (istub)" << be_nl
<< "{\n";
os->incr_indent (0);
// STEP 5C:
// do any pre do_call processing with return type. This includes
// allocating memory, initialization.
ctx = *this->ctx_;
ctx.state (TAO_CodeGen::TAO_OPERATION_RETVAL_PRE_DOCALL_CS);
@@ -365,13 +365,13 @@ be_visitor_operation_cs::visit_operation (be_operation *node)
ACE_ERROR_RETURN ((LM_ERROR,
"(%N:%l) be_visitor_operation_cs::"
"visit_operation - "
- "codegen for retval pre do_call failed\n"),
+ "codegen for retval pre do_static_call failed\n"),
-1);
}
// STEP 5D:
// do any pre do_call stuff with arguments
ctx = *this->ctx_;
ctx.state (TAO_CodeGen::TAO_OPERATION_ARG_PRE_DOCALL_CS);
visitor = tao_cg->make_visitor (&ctx);
@@ -381,14 +381,14 @@ be_visitor_operation_cs::visit_operation (be_operation *node)
ACE_ERROR_RETURN ((LM_ERROR,
"(%N:%l) be_visitor_operation_cs::"
"visit_operation - "
- "codegen for argument pre do_call failed\n"),
+ "codegen for argument pre do_static_call failed\n"),
-1);
}
// STEP 5E:
// call do_call with appropriate number of arguments
os->indent ();
- *os << "istub->do_call (" << be_idt_nl
+ *os << "istub->do_static_call (" << be_idt_nl
<< "_tao_environment, " << be_nl
<< "&";
// check if we are an attribute node in disguise
@@ -412,7 +412,7 @@ be_visitor_operation_cs::visit_operation (be_operation *node)
ACE_ERROR_RETURN ((LM_ERROR,
"(%N:%l) be_visitor_operation_cs::"
"visit_operation - "
- "codegen for return var in do_call failed\n"),
+ "codegen for return var in do_static_call failed\n"),
-1);
}
// insert a comma after the return val if there are arguments
@@ -421,7 +421,7 @@ be_visitor_operation_cs::visit_operation (be_operation *node)
*os << ",\n";
}
// pass each argument to do_call
ctx = *this->ctx_;
ctx.state (TAO_CodeGen::TAO_OPERATION_ARG_DOCALL_CS);
visitor = tao_cg->make_visitor (&ctx);
@@ -431,11 +431,11 @@ be_visitor_operation_cs::visit_operation (be_operation *node)
ACE_ERROR_RETURN ((LM_ERROR,
"(%N:%l) be_visitor_operation_cs::"
"visit_operation - "
- "codegen for return var in do_call failed\n"),
+ "codegen for return var in do_static_call failed\n"),
-1);
}
- // end the do_call
+ // end the do_static_call
*os << be_uidt_nl;
*os << ");\n";
@@ -450,7 +450,7 @@ be_visitor_operation_cs::visit_operation (be_operation *node)
ACE_ERROR_RETURN ((LM_ERROR,
"(%N:%l) be_visitor_operation_cs::"
"visit_operation - "
- "codegen for return type post do_call failed\n"),
+ "codegen for return type post do_static_call failed\n"),
-1);
}
@@ -464,7 +464,7 @@ be_visitor_operation_cs::visit_operation (be_operation *node)
ACE_ERROR_RETURN ((LM_ERROR,
"(%N:%l) be_visitor_operation_cs::"
"visit_operation - "
- "codegen for args in post do_call failed\n"),
+ "codegen for args in post do_static_call failed\n"),
-1);
}
@@ -1901,7 +1901,7 @@ be_visitor_operation_rettype_vardecl_cs::visit_union (be_union *node)
// be_visitor_operation_rettype_pre_docall_cs
//
// This visitor generates code that passes the return type variable to the
-// do_call method
+// do_static_call method
// *****************************************************************************
be_visitor_operation_rettype_pre_docall_cs::
@@ -2012,7 +2012,7 @@ be_visitor_operation_rettype_pre_docall_cs::visit_union (be_union *node)
// be_visitor_operation_rettype_docall_cs
//
// This visitor generates code that passes the return type variable to the
-// do_call method
+// do_static_call method
// *****************************************************************************
be_visitor_operation_rettype_docall_cs::be_visitor_operation_rettype_docall_cs
@@ -2146,7 +2146,7 @@ be_visitor_operation_rettype_docall_cs::visit_union (be_union *node)
// be_visitor_operation_rettype_post_docall_cs
//
// This visitor generates code that passes the return type variable to the
-// do_call method
+// do_static_call method
// ********************************************************************************
be_visitor_operation_rettype_post_docall_cs::
@@ -2914,7 +2914,7 @@ be_visitor_operation_rettype_post_upcall_ss::visit_union (be_union *node)
}
// ************************************************************
// generic operation visitor to handle the pre/post do_call/upcall stuff with
// arguments
// ************************************************************
@@ -347,14 +347,14 @@ be_visitor_operation_cs::visit_operation (be_operation *node)
// STEP 5B:
// generate code that retrieves the underlying stub object and then
- // invokes do_call on it.
+ // invokes do_static_call on it.
*os << "STUB_Object *istub = this->stubobj (_tao_environment);" << be_nl
<< "if (istub)" << be_nl
@@ -347,14 +347,14 @@ be_visitor_operation_cs::visit_operation (be_operation *node)
os->incr_indent (0);
// STEP 5C:
- // do any pre do_call processing with return type. This includes
+ // do any pre do_static_call processing with return type. This includes
// allocating memory, initialization.
ctx = *this->ctx_;
@@ -365,13 +365,13 @@ be_visitor_operation_cs::visit_operation (be_operation *node)
}
// STEP 5D:
- // do any pre do_call stuff with arguments
+ // do any pre do_static_call stuff with arguments
ctx = *this->ctx_;
ctx.state (TAO_CodeGen::TAO_OPERATION_ARG_PRE_DOCALL_CS);
@@ -381,14 +381,14 @@ be_visitor_operation_cs::visit_operation (be_operation *node)
}
// STEP 5E:
- // call do_call with appropriate number of arguments
+ // call do_static_call with appropriate number of arguments
os->indent ();
@@ -421,7 +421,7 @@ be_visitor_operation_cs::visit_operation (be_operation *node)
*os << ",\n";
}
- // pass each argument to do_call
+ // pass each argument to do_static_call
ctx = *this->ctx_;
ctx.state (TAO_CodeGen::TAO_OPERATION_ARG_DOCALL_CS);
@@ -2914,7 +2914,7 @@ be_visitor_operation_rettype_post_upcall_ss::visit_union (be_union *node)
}
// ************************************************************
-// generic operation visitor to handle the pre/post do_call/upcall stuff with
+// generic operation visitor to handle the pre/post do_static_call/upcall stuff with
// arguments
// ************************************************************